#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 config-schema
version:              1.3.0.0
visibility:           public
id:                   config-schema-1.3.0.0-Jn18oyAefqZCOmTjErXFE8
key:                  config-schema-1.3.0.0-Jn18oyAefqZCOmTjErXFE8
license:              ISC
copyright:            Eric Mertens 2017
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/config-schema
synopsis:             Schema definitions for the config-value package
description:
    This package makes it possible to define schemas for use when
    loading configuration files using the config-value format.
    These schemas can be used to process a configuration file into
    a Haskell value or to automatically generate documentation for
    the file format.

category:             Language
abi:                  7a8b2146a3bad39d9a7ca738d272b6d2
exposed:              True
exposed-modules:
    Config.Schema Config.Schema.Docs Config.Schema.Load
    Config.Schema.Load.Error Config.Schema.Spec Config.Schema.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/config-schema-1.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/config-schema-1.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/config-schema-1.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-config-schema
hs-libraries:         HSconfig-schema-1.3.0.0-Jn18oyAefqZCOmTjErXFE8
depends:
    base-4.18.2.1 config-value-0.8.3-IWIlPmbx9u07ZPnTUBDeDU
    containers-0.6.7 free-5.2-AR7GiDYG5Zn11znBIXJLbO
    kan-extensions-5.2.7-KvCtNk4vBeRBBiS6ND7ztw pretty-1.1.3.6
    semigroupoids-6.0.2-887K3a1BQFJ8a6cHyZLy3I text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-config-schema/html/config-schema.haddock

haddock-html:         /usr/share/doc/haskell-config-schema/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

